@@ -963,6 +963,39 @@ Unix 纪元时间是 1970 年 1 月 1 日星期四，协调世界时 (UTC) 。
         self.CreationTimestamp = params.get("CreationTimestamp")
 
 
+class ImageRect(AbstractModel):
+    """图像坐标信息。
+
+    """
+
+    def __init__(self):
+        """
+        :param X: 左上角横坐标。
+        :type X: int
+        :param Y: 左上角纵坐标。
+        :type Y: int
+        :param Width: 人体宽度。
+        :type Width: int
+        :param Height: 人体高度。
+        :type Height: int
+        :param Label: 分割选项名称。
+        :type Label: str
+        """
+        self.X = None
+        self.Y = None
+        self.Width = None
+        self.Height = None
+        self.Label = None
+
+
+    def _deserialize(self, params):
+        self.X = params.get("X")
+        self.Y = params.get("Y")
+        self.Width = params.get("Width")
+        self.Height = params.get("Height")
+        self.Label = params.get("Label")
+
+
 class KeyPointInfo(AbstractModel):
     """人体关键点信息
 
@@ -1334,17 +1367,27 @@ class SegmentCustomizedPortraitPicResponse(AbstractModel):
         :type PortraitImage: str
         :param MaskImage: 指定标签处理后的Mask。一个通过 Base64 编码的文件，解码后文件由 Float 型浮点数组成。这些浮点数代表原图从左上角开始的每一行的每一个像素点，每一个浮点数的值是原图相应像素点位于人体轮廓内的置信度（0-1）转化的灰度值（0-255）
         :type MaskImage: str
+        :param ImageRects: 坐标信息。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ImageRects: list of ImageRect
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
         self.PortraitImage = None
         self.MaskImage = None
+        self.ImageRects = None
         self.RequestId = None
 
 
     def _deserialize(self, params):
         self.PortraitImage = params.get("PortraitImage")
         self.MaskImage = params.get("MaskImage")
+        if params.get("ImageRects") is not None:
+            self.ImageRects = []
+            for item in params.get("ImageRects"):
+                obj = ImageRect()
+                obj._deserialize(item)
+                self.ImageRects.append(obj)
         self.RequestId = params.get("RequestId")
 
 
