@@ -54,6 +54,34 @@ class GseClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CopyFleet(self, request):
+        """本接口（CopyFleet）用于复制服务器舰队。
+
+        :param request: Request instance for CopyFleet.
+        :type request: :class:`tencentcloud.gse.v20191112.models.CopyFleetRequest`
+        :rtype: :class:`tencentcloud.gse.v20191112.models.CopyFleetResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CopyFleet", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CopyFleetResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateAlias(self, request):
         """本接口（CreateAlias）用于创建别名。
 
